/** 
* @name Сообщение от датчика в режиме "Охрана" 
* @desc При срабатывании датчика отправляется сообщение на e-mail 
*/
const actor1 = Device("ActorD", "Канал индикации охраны"); 
const actor2 = Device("ActorD", "Канал сирены"[
  {"name":"timeOff", "note":"Сирена включена, сек", "type":"number", "val":30}
  ]);
const sensor = Device("SensorD", "Датчик"); 

const script = {
    check() {
      return ((actor1.dval == 1) && ((actor2.dval == 0) && (sensor.dval == 1) || (actor2.dval > 0)));  
    },
    
    start() {
         this.addTimer("T1"); // Таймер нужно объявить, т к он участвует в функции onSensor
         
        if (actor2.dval == 0 && sensor.dval == 1) {
          // Cирена выключена, датчик сработал  
          this.do(actor2, "on");
          this.info("email", "OWNER", 'Тревога!')
        } else {
          // датчик выключен - взводим таймер, чтобы отключить 
          this.startTimer("T1", actor2.timeOff, "turnOff");       
        }
        // В любом случае следим за датчиком и сиреной
        this.addListener(sensor, "onSensor");
        this.addListener(actor2, "onActor2");
    },
    
    onSensor() {
       // Если датчик выключен - взводим таймер
      if (!sensor.dval && this.timer.T1 == "off")  {
        this.startTimer("T1", actor2.timeOff, "turnOff");
      }  
        
       // Если датчик сработал опять - сбрасываем таймер
      if (sensor.dval && this.timer.T1 == 'on')  {
        this.stopTimer('T1');
      }  
    },
    
     onActor2() {
      // Индикатор охраны выключен - выходим
       if (actor1.dval) this.exit();
     },
     
    // Функция, которая сработает, когда таймер досчитает (не срабатывает датчик в течении заданного времени) - отключаем и выходим
    turnOff() {
      this.do(actor2, "off");
      this.exit();
    }
};
